/*
 * Segment 6 Intelligente Bewertungsverfahren, SWE 6.1 Stauverlaufsanalyse
 * Copyright (C) 2007 BitCtrl Systems GmbH
 *
 * This program is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation; either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 51
 * Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.ibv.anastau.anastau;

import java.util.ResourceBundle;
import java.util.logging.Level;

import de.bsvrz.sys.funclib.bitctrl.daf.LogNachricht;
import de.bsvrz.sys.funclib.debug.Debug;
import de.bsvrz.sys.funclib.operatingMessage.MessageGrade;

/**
 * die allgemeinen Meldungen innerhalb der Softwareeinheit
 * "Stauverlaufsanalyse".
 *
 * @author BitCtrl Systems GmbH, Peuker
 */
public enum SvaMessage implements LogNachricht {

	/* Meldungen die mit dem Level ERROR ausgegeben werden sollen . */

	/** Parameter 1) Meldung der Exception. */
	ErrorSendeStauEigenschaften(Debug.ERROR),

	/** Parameter 1) Meldung der Exception. */
	ErrorStauObjektLoeschen(Debug.ERROR),

	/** Parameter 1) Meldung der Exception. */
	ErrorStauObjektAnlegen(Debug.ERROR),

	/** Parameter 1) die Schrittweite. */
	ErrorSchrittweitePrognose(Debug.ERROR),

	/** Parameter 1) die Fehlermeldung. */
	ErrorSvaParameterAnmeldung(Debug.ERROR),

	/** Parameter 1) der Thread 2) die Fehlermeldung. */
	ErrorThreadFehler(Debug.ERROR),

	/* Meldungen die mit dem Level WARNING ausgegeben werden sollen . */

	/** Parameter 1) die Strasse. */
	WarningZirkulaereStrasse(Debug.WARNING),

	/** Parameter 1) der Messquerschnitt. */
	WarningKeinStsFuerMq(Debug.WARNING),

	/** Parameter 1) Zeitpunkt 2)Stauobjekt 3) Grund. */
	WarningKeinePrognoseDaten(Debug.WARNING),

	/** Parameter 1) Stauobjekt 2) Intervall. */
	WarningKeineGanglinie(Debug.WARNING),

	/** Parameter 1) Stauobjekt 2) Intervall 3) Fehlermeldung. */
	WarningGanglinienAbfrage(Debug.WARNING),

	/** Parameter 1) Messquerschnitt. */
	WarningKeinQ0Wert(Debug.WARNING),

	/** Parameter 1) Stauobjekt 2) Störfallindikator. */
	WarningIndikatorOhneStau(Debug.WARNING),

	/** Parameter 1) Störfallindikator. */
	WarningKeineAbfahrtsDatenImStau(Debug.WARNING),

	/** Parameter 1) Störfallindikator. */
	WarningKeineZufahrtsDatenImStau(Debug.WARNING);

	/**
	 * das verwendete Ressource-Bundle.
	 */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(SvaMessage.class.getCanonicalName());

	/** der Level mit dem die Meldung ausgegeben werden soll. */
	private Level level;

	/**
	 * Initialisiert das Objekt.
	 *
	 * @param level
	 *            der Log-Level.
	 */
	SvaMessage(final Level level) {
		this.level = level;
	}

	@Override
	public MessageGrade getBmvLevel() {
		MessageGrade result = null;
		if (level.equals(Debug.WARNING)) {
			result = MessageGrade.WARNING;
		} else if (level.equals(Debug.ERROR)) {
			result = MessageGrade.ERROR;
		}
		return result;
	}

	@Override
	public Level getLogLevel() {
		return level;
	}

	@Override
	public ResourceBundle getResourceBundle() {
		return SvaMessage.RESOURCE_BUNDLE;
	}

	@Override
	public String toString() {
		return getResourceBundle().getString(name());
	}

}
